EXPORTS
	_ZN8CCFLogIf5WriteERK6TDesC8S2_RK7TDesC16 @ 1 NONAME ; CCFLogIf::Write(TDesC8 const&, TDesC8 const&, TDesC16 const&)
	_ZN8CCFLogIf7ConnectEv @ 2 NONAME ; CCFLogIf::Connect(void)
	_ZN8CCFLogIf7ContextEv @ 3 NONAME ; CCFLogIf::Context(void)
	_ZN8CCFLogIf6DeleteEPS_ @ 4 NONAME ; CCFLogIf::Delete(CCFLogIf*)
	_ZN8CCFLogIf7HexDumpERK6TDesC8S2_PKtS4_PKhi @ 5 NONAME ; CCFLogIf::HexDump(TDesC8 const&, TDesC8 const&, unsigned short const*, unsigned short const*, unsigned char const*, int)
	_ZN8CCFLogIf4NewLEv @ 6 NONAME ; CCFLogIf::NewL(void)
	_ZN8CCFLogIf5PanicE11TCFLogPanic @ 7 NONAME ; CCFLogIf::Panic(TCFLogPanic)
	_ZN8CCFLogIf10SetContextEv @ 8 NONAME ; CCFLogIf::SetContext(void)
	_ZN8CCFLogIf11WriteBinaryERK6TDesC8S2_S2_ @ 9 NONAME ; CCFLogIf::WriteBinary(TDesC8 const&, TDesC8 const&, TDesC8 const&)
	_ZN8CCFLogIf11WriteFormatERK6TDesC8S2_11TRefByValueIS1_ERSt9__va_list @ 10 NONAME ;  CCFLogIf::WriteFormat(TDesC8 const&, TDesC8 const&, TRefByValue<TDesC8 const>, signed char*(&)[0])
	_ZN8CCFLogIf11WriteFormatERK6TDesC8S2_11TRefByValueIS1_Ez @ 11 NONAME ; CCFLogIf::WriteFormat(TDesC8 const&, TDesC8 const&, TRefByValue<TDesC8 const>, ...)
	_ZN8CCFLogIf11WriteFormatERK6TDesC8S2_11TRefByValueIK7TDesC16ERSt9__va_list @ 12 NONAME ;  CCFLogIf::WriteFormat(TDesC8 const&, TDesC8 const&, TRefByValue<TDesC16 const>, signed char*(&)[0])
	_ZN8CCFLogIf11WriteFormatERK6TDesC8S2_11TRefByValueIK7TDesC16Ez @ 13 NONAME ; CCFLogIf::WriteFormat(TDesC8 const&, TDesC8 const&, TRefByValue<TDesC16 const>, ...)
	_ZN8CCFLogIf5WriteERK6TDesC8S2_S2_ @ 14 NONAME ; CCFLogIf::Write(TDesC8 const&, TDesC8 const&, TDesC8 const&)
	_ZN8CCFLogIf5CloseEv @ 15 NONAME ; CCFLogIf::Close(void)

